Package: BrazilDataAPI
Type: Package
Title: Access Brazilian Data via APIs and Curated Datasets
Version: 0.3.0
Maintainer: Renzo Caceres Rossi <arenzocaceresrossi@gmail.com>
Description: Provides functions to access data from the 'BrasilAPI', 'Nager.Date API', 
    and 'World Bank API', related to Brazil's postal codes, banks, holidays,
    company registrations, and economic development data. Additionally, the package includes
    curated datasets related to Brazil, covering topics such as demographic data (males and
    females by state and year), river levels, environmental emission factors, film festivals,
    and yellow fever outbreak records. The package supports research and analysis focused on
    Brazil by integrating open APIs with high-quality datasets from multiple domains. For more
    information on the APIs, see: 
    'BrasilAPI' <https://brasilapi.com.br/>, 
    'Nager.Date' <https://date.nager.at/Api>, 
    'World Bank API' <https://datahelpdesk.worldbank.org/knowledgebase/articles/889392>.
License: GPL-3
URL: https://github.com/lightbluetitan/brazildataapi,
        https://lightbluetitan.github.io/brazildataapi/
BugReports: https://github.com/lightbluetitan/brazildataapi/issues
Encoding: UTF-8
Depends: R (>= 4.1.0)
Imports: utils, httr, jsonlite, dplyr, scales, tibble
Suggests: ggplot2, testthat (>= 3.0.0), knitr, rmarkdown
Authors@R: 
    person(
        given = "Renzo",
        family = "Caceres Rossi",
        role = c("aut", "cre"),
        email = "arenzocaceresrossi@gmail.com",
        comment = c(ORCID = "0009-0005-0744-854X")
    )
Config/testthat/edition: 3
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-02 08:49:26 UTC; Renzo
Author: Renzo Caceres Rossi [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-0744-854X>)
Repository: CRAN
Date/Publication: 2026-07-02 23:00:11 UTC
Built: R 4.6.0; ; 2026-07-03 00:04:23 UTC; unix
