# Generated by roxygen2: do not edit by hand

export(Brasil_females_df)
export(Brasil_males_df)
export(Brazil_films_df)
export(Yellow_Fever_list)
export(get_brazil_banks)
export(get_brazil_cep)
export(get_brazil_child_mortality)
export(get_brazil_cnpj)
export(get_brazil_cpi)
export(get_brazil_energy_use)
export(get_brazil_gdp)
export(get_brazil_holidays)
export(get_brazil_hospital_beds)
export(get_brazil_life_expectancy)
export(get_brazil_literacy_rate)
export(get_brazil_municipalities)
export(get_brazil_population)
export(get_brazil_rate_name)
export(get_brazil_rates)
export(get_brazil_unemployment)
export(manaus_ts)
export(sp_emission_factors_df)
export(view_datasets_BrazilDataAPI)
importFrom(dplyr,as_tibble)
importFrom(dplyr,mutate)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(httr,status_code)
importFrom(jsonlite,fromJSON)
importFrom(scales,comma)
importFrom(tibble,tibble)
